%define pypi_name reportlab

Summary:	ReportLab library to create PDF documents using Python
Name:		python-reportlab
Version:	3.6.2
Release:	%mkrel 1
License:	BSD
Group:		Publishing
URL:		https://pypi.org/project/reportlab
Source0:	%{pypi_source}
Patch0:         linking.patch
BuildRequires:	pkgconfig(freetype2)

%description
ReportLab is a library that lets you directly create documents in
Adobe's Portable Document Format (PDF) using the Python programming
language.

ReportLab library creates PDF based on graphics commands without
intervening steps. It's therefore extremely fast, and flexible (since
you're using a full-blown programming language).

Sample use cases are:

  * Dynamic PDF generation on the web
  * High-volume corporate reporting and database publishing
  * As embeddable print engine for other applications, including a
    'report language' so that users can customize their own reports.
  * As 'build system' for complex documents with charts, tables and text
    such as management accounts, statistical reports and scientific papers
  * from XML to PDF in one step

%package -n python3-reportlab
Summary:	ReportLab library to create PDF documents using Python 3
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-pillow
Requires:	fonts-ttf-dejavu
Requires:	python3-pillow
%{?python_provide:%python_provide python3-reportlab}

%description -n python3-reportlab
ReportLab is a library that lets you directly create documents in
Adobe's Portable Document Format (PDF) using the Python programming
language.

ReportLab library creates PDF based on graphics commands without
intervening steps. It's therefore extremely fast, and flexible (since
you're using a full-blown programming language).

%package docs
Summary:	Documentation files for %{name}
Requires:	%{name} = %{version}-%{release}
Group:		Publishing
License:	BSD

%description docs
Contains the documentation for ReportLab.

%prep
%setup -q -n reportlab-%{version}
%autopatch -p1

# clean up hashbangs from libraries
find src -name '*.py' | xargs sed -i -e '/^#!\//d'

# drop bundled egg-info
rm -rf src/reportlab.egg-info/

%build
%py3_build

# a bit of a horrible hack due to a chicken-and-egg problem. The docs
# require reportlab, which isn't yet installed, but is at least built.
PYTHONPATH="$(pwd)/$(ls -d build/lib*%{python3_version})" %{__python3} docs/genAll.py

%install
%py3_install

# Remove bundled fonts
rm -rf %{buildroot}%{python3_sitearch}/reportlab/fonts

%files -n python3-reportlab
%license LICENSE.txt
%doc README.txt CHANGES.md
%{python3_sitearch}/reportlab
%{python3_sitearch}/reportlab*.egg-info

%files docs
%doc docs/*.pdf demos tools


%changelog
* Sat Nov 13 2021 wally <wally> 3.6.2-1.mga8
+ Revision: 1756065
- new version 3.6.2 (mga#29592)

* Sat Jan 02 2021 luigiwalser <luigiwalser> 3.5.57-1.mga8
+ Revision: 1668057
- 3.5.57

* Wed Dec 30 2020 luigiwalser <luigiwalser> 3.5.56-1.mga8
+ Revision: 1665823
- 3.5.56

* Sat Nov 07 2020 guillomovitch <guillomovitch> 3.5.55-1.mga8
+ Revision: 1643241
- new version 3.5.55

* Mon Sep 14 2020 guillomovitch <guillomovitch> 3.5.49-1.mga8
+ Revision: 1626398
- new version 3.5.49

* Tue Mar 31 2020 daviddavid <daviddavid> 3.5.42-1.mga8
+ Revision: 1562592
- new version: 3.5.42

* Wed Feb 19 2020 umeabot <umeabot> 3.5.34-2.mga8
+ Revision: 1543585
- Mageia 8 Mass Rebuild

* Tue Jan 21 2020 daviddavid <daviddavid> 3.5.34-1.mga8
+ Revision: 1481980
- new version: 3.5.34, fixes CVE-2019-17626 (mga#26115)

* Wed Nov 13 2019 daviddavid <daviddavid> 3.5.32-1.mga8
+ Revision: 1459721
- new version: 3.5.32

* Thu Oct 10 2019 daviddavid <daviddavid> 3.5.28-1.mga8
+ Revision: 1450912
- new version: 3.5.28
+ wally <wally>
- add patch to fix linking

* Sat Sep 14 2019 tv <tv> 3.5.19-2.mga8
+ Revision: 1440580
- rebuild for python-3.8
- drop python2 subpkg
- "fix" underlinking

* Sat Apr 20 2019 wally <wally> 3.5.19-1.mga7
+ Revision: 1393838
- new version 3.5.19

* Sun Jan 20 2019 luigiwalser <luigiwalser> 3.5.13-1.mga7
+ Revision: 1358172
- 3.5.13

* Mon Jan 07 2019 shlomif <shlomif> 3.5.12-2.mga7
+ Revision: 1351162
- Rebuild for python3 3.7

* Mon Dec 31 2018 luigiwalser <luigiwalser> 3.5.12-1.mga7
+ Revision: 1347676
- 3.5.12

* Sun Sep 23 2018 umeabot <umeabot> 3.4.0-4.mga7
+ Revision: 1300585
- Mageia 7 Mass Rebuild

* Mon Apr 23 2018 kekepower <kekepower> 3.4.0-3.mga7
+ Revision: 1221518
- Rename python-reportlab to python2-reportlab
- Use python_provide

* Fri Aug 04 2017 tv <tv> 3.4.0-2.mga7
+ Revision: 1134666
- rebuild for new python
+ philippem <philippem>
- update to 3.4.0

* Mon Feb 22 2016 philippem <philippem> 3.3.0-1.mga6
+ Revision: 976113
- update to 3.3.0

* Tue Feb 16 2016 umeabot <umeabot> 3.2.0-4.mga6
+ Revision: 962434
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 tv <tv> 3.2.0-3.mga6
+ Revision: 889125
+ rebuild (emptylog)

* Sat Oct 10 2015 tv <tv> 3.2.0-2.mga6
+ Revision: 888970
- rebuild for python 3.5

* Tue Sep 08 2015 philippem <philippem> 3.2.0-1.mga6
+ Revision: 874235
- update to 3.2.0

* Wed Oct 15 2014 umeabot <umeabot> 3.1.8-5.mga5
+ Revision: 740309
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.1.8-4.mga5
+ Revision: 726909
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.1.8-3.mga5
+ Revision: 688307
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 3.1.8-2.mga5
+ Revision: 628989
- Rebuild for new Python

* Thu Apr 24 2014 philippem <philippem> 3.1.8-1.mga5
+ Revision: 617694
- update to 3.1.8

* Mon Mar 17 2014 philippem <philippem> 3.0-1.mga5
+ Revision: 604488
- update to 3.0, add Python3

* Tue Oct 22 2013 umeabot <umeabot> 2.7-4.mga4
+ Revision: 544237
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.7-3.mga4
+ Revision: 499287
- Rebuild to add different pythonegg provides for python 2 and 3
+ philippem <philippem>
- cleaning spec

* Tue Jul 02 2013 philippem <philippem> 2.7-1.mga4
+ Revision: 449800
- new version 2.7

* Sun Jan 13 2013 umeabot <umeabot> 2.5-6.mga3
+ Revision: 379435
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Feb 17 2011 philippem <philippem> 2.5-5.mga1
+ Revision: 52985
- fix missing group for docs #31

* Fri Feb 11 2011 philippem <philippem> 2.5-4.mga1
+ Revision: 49993
- fix linkage
- imported package python-reportlab

